@@ -1,5 +1,5 @@
-# WordNet::Similarity::ICFinder.pm version 0.10
-# (Updated 9/01/2004 -- Jason)
+# WordNet::Similarity::ICFinder.pm version 1.03
+# (Last updated $Id: ICFinder.pm,v 1.15 2006/04/14 07:58:26 sidz1979 Exp $)
 #
 # A generic (and abstract) information content measure--this is not a
 # real measure.  The res, lin, and jcn measures inherit from this class.
@@ -96,7 +96,7 @@ use WordNet::Similarity::PathFinder;
 
 our @ISA = qw/WordNet::Similarity::PathFinder/;
 
-our $VERSION = '0.10';
+our $VERSION = '1.03';
 
 WordNet::Similarity::addConfigOption ('infocontent', 0, 'p', undef);
 
@@ -127,26 +127,24 @@ then $mode must be 'offset'.
 
 sub probability {
   my $self = shift;
-  my $con = shift;
-  my $pos = shift;
+  my $wn = $self->{wn};
+  my ($offset, $pos, $mode) = @_;
+
+  $offset = $wn->offset($offset) if(defined($mode) && $mode eq 'wps');
+
   my $class = ref $self || $self;
 
   my $rootFreq = $self->{offsetFreq}->{$pos}->{0};
-  my $conFreq = $self->{offsetFreq}->{$pos}->{$con};
-  if($rootFreq && defined $conFreq) {
-    if($conFreq <= $rootFreq) {
-      return $conFreq / $rootFreq;
-    }
-    else {
-      $self->{errorString} .= "\nError (${class}::probability()) - ";
-      $self->{errorString} .= "Probability greater than 1? (Check information content file)";
-      $self->{error} = 2;
-      return 0;
+  my $offFreq = $self->{offsetFreq}->{$pos}->{$offset};
+  if($rootFreq && defined $offFreq) {
+    if($offFreq <= $rootFreq) {
+      return $offFreq / $rootFreq;
     }
+    $self->{errorString} .= "\nError (${class}::probability()) - ";
+    $self->{errorString} .= "Probability greater than 1? (Check information content file)";
+    $self->{error} = 2;
   }
-  else {
-    return 0;
-  }
+  return 0;
 }
 
 
@@ -161,10 +159,13 @@ then $mode must be 'wps'; if $synset is an offset, then $mode must be
 sub IC
 {
   my $self = shift;
-  my $offset = shift;
-  my $pos = shift;
+  my $wn = $self->{wn};
+  my ($offset, $pos, $mode) = @_;
+
+  $offset = $wn->offset($offset) if(defined($mode) && $mode eq 'wps');
+
   if($pos =~ /[nv]/) {
-    my $prob = $self->probability($offset, $pos);
+    my $prob = $self->probability($offset, $pos, 'offset');
     return ($prob > 0) ? -log($prob) : 0;
   }
   return 0;
@@ -201,6 +202,105 @@ sub getFrequency
   return $freq;
 }
 
+=item getLCSbyIC($synset1, $synset2, $pos, $mode)
+
+Given two input synsets, finds the least common subsumer (LCS) of them.  If
+there are multiple candidates for the LCS, the the candidate with the greatest
+information content.
+
+Parameters: two synsets, a part of speech, and a mode.
+
+Returns: a list of the form ($lcs, $ic) where $lcs is the LCS and $ic is
+the information content of the LCS.
+
+=cut
+
+sub getLCSbyIC
+{
+  my $self = shift;
+  my $synset1 = shift;
+  my $synset2 = shift;
+  my $pos = shift;
+  my $mode = shift;
+  my $class = ref $self || $self;
+
+  my $wn = $self->{wn};
+
+  my @paths = $self->getAllPaths ($synset1, $synset2, $pos, $mode);
+
+  # check to see if any paths were found
+  unless (defined $paths[0]) {
+    $self->{error} = $self->{error} < 1 ? 1 : $self->{error};
+    $self->{errorString} .= "\nWarning (${class}::getLCSbyIC()) - ";
+
+    my $wps1 = $mode eq 'wps' ? $synset1 : $wn->getSense ($synset1, $pos);
+    my $wps2 = $mode eq 'wps' ? $synset2 : $wn->getSense ($synset2, $pos);
+
+    $self->{errorString} .= "No LCS found for $wps1 and $wps2.";
+
+    if ($self->{trace}) {
+      $self->{traceString} .= "\nNo LCS found for ";
+      $self->printSet ($pos, $mode, $synset1);
+      $self->{traceString} .= ", ";
+      $self->printSet ($pos, $mode, $synset2);
+      $self->{traceString} .= ".";
+    }
+    return undef;
+  }
+
+  my %IC;
+
+  # get the IC of each subsumer, put it in a hash
+  foreach (@paths) {
+    # the "O + $off" below is a hack to cope with an unfortunate problem:
+    # The offsets in the WordNet data files are zero-padded, eight-digit
+    # decimal numbers.  Sometimes these numbers get stripped off (QueryData's
+    # offset() method does this).  As a result, it is much easier to compare
+    # the offsets as numbers rather than as strings:
+    # '00001740' ne '1740', BUT 0 + '00001740' == 0 + '1740'
+    my $off;
+    if ($mode eq 'offset') {
+      $off = $_->[0];
+    }
+    else {
+      $off = (index ($_->[0], '*Root*') < $[) ? $wn->offset ($_->[0]) : 0;
+    }
+
+    next if defined $IC{$_->[0]};
+
+   $IC{$_->[0]} = $self->IC (0 + $off, $pos) || 0;
+  }
+
+
+  # sort lcs by info content
+  my @array = sort {$b->[1] <=> $a->[1]} map {[$_, $IC{$_}]} keys %IC;
+
+  if ($self->{trace}) {
+    $self->{traceString} .= "Lowest Common Subsumer(s): ";
+  }
+
+  my @return;
+
+  # determine which subsumers have the highest info content; do some
+  # tracing as well
+  foreach my $ref (@array) {
+    if ($self->{trace}) {
+      $self->printSet ($pos, $mode, $ref->[0]);
+      $self->{traceString} .= " (IC=";
+      $self->{traceString} .= sprintf ("%.6f", $ref->[1]);
+      $self->{traceString} .= ") ";
+    }
+
+    if ($ref->[1] == $array[0]->[1]) {
+      push @return, $ref;
+    }
+  }
+
+  $self->{trace} and $self->{traceString} .= "\n";
+
+  return @return;
+}
+
 
 =item $module->configure (Z<>)
 
@@ -436,15 +536,15 @@ __END__
 
 =head1 AUTHORS
 
+  Ted Pedersen, University of Minnesota Duluth
+  tpederse at d.umn.edu
+
   Jason Michelizzi, Univeristy of Minnesota Duluth
   mich0212 at d.umn.edu
 
   Siddharth Patwardhan, University of Utah, Salt Lake City
   sidd at cs.utah.edu
 
-  Ted Pedersen, University of Minnesota Duluth
-  tpederse at d.umn.edu
-
 =head1 BUGS
 
 None.
@@ -461,7 +561,7 @@ WordNet::Similarity::jcn(3)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004, Jason Michelizzi, Siddharth Patwardhan, and Ted Pedersen
+Copyright (c) 2005, Ted Pedersen, Jason Michelizzi and Siddharth Patwardhan
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
