@@ -1,7 +1,7 @@
-#!/usr/local/bin/perl -w
+#! /usr/local/bin/perl -w
 #
-# rawtextFreq.pl version 0.09
-# (Updated 05/17/2004 -- Jason)
+# rawtextFreq.pl version 1.01
+# (Last updated $Id: rawtextFreq.pl,v 1.16 2005/12/11 22:37:02 sidz1979 Exp $)
 #
 # This program reads raw text and computes the frequency counts
 # for each synset in WordNet. These frequency counts are used by
@@ -9,8 +9,37 @@
 # content values of concepts. The output is generated in a format as
 # required by the WordNet::Similarity modules for computing
 # semantic relatedness.
-use strict;
+#
+# Copyright (c) 2005
+#
+# Ted Pedersen, University of Minnesota, Duluth
+# tpederse at d.umn.edu
+#
+# Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
+# banerjee+ at cs.cmu.edu
+#
+# Siddharth Patwardhan, University of Utah, Salt Lake City
+# sidd at cs.utah.edu
+#
+# Jason Michelizzi, University of Minnesota, Duluth
+# mich0212 at d.umn.edu
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+#
+# -----------------------------------------------------------------------------
 
+use strict;
 use File::Find;
 
 # Variable declarations
@@ -137,8 +166,8 @@ elsif (defined $ENV{WNHOME})
 }
 else
 {
-    $wnPCPath = "C:\\Program Files\\WordNet\\2.0\\dict";
-    $wnUnixPath = "/usr/local/WordNet-2.0/dict";
+    $wnPCPath = "C:\\Program Files\\WordNet\\2.1\\dict";
+    $wnUnixPath = "/usr/local/WordNet-2.1/dict";
 }
 
 # Load up WordNet
@@ -335,7 +364,7 @@ sub compoundify
 
     while($firstPointer <= $#wordsArray)
     {
-	$secondPointer = $#wordsArray;
+	$secondPointer = (($firstPointer + 5 < $#wordsArray)?($firstPointer + 5):($#wordsArray));
 	$done = 0;
 	while($secondPointer > $firstPointer && !$done)
 	{
@@ -459,7 +488,7 @@ sub getHyponymOffsets
 	return [@retVal];
     }
     $wordForm = $wn->getSense($offset, $pos);
-    @hyponyms = $wn->querySense($wordForm, "hypo");
+    @hyponyms = $wn->querySense($wordForm, "hypos");
     if(!@hyponyms || $#hyponyms < 0)
     {
 	return undef;
@@ -608,8 +637,8 @@ EOT
 # Subroutine to print the version information
 sub printVersion
 {
-    print "rawtextFreq.pl version 0.09\n";
-    print "Copyright (C) 2002-2004 Ted Pedersen, Satanjeev Banerjee & Siddharth Patwardhan.\n";
+    print "rawtextFreq.pl version 1.01\n";
+    print "Copyright (c) 2005, Ted Pedersen, Satanjeev Banerjee, Siddharth Patwardhan and Jason Michelizzi.\n";
 }
 
 __END__
@@ -622,8 +651,8 @@ files
 =head1 SYNOPSIS
 
 rawtextFreq.pl --compfile COMPFILE --outfile OUTFILE [--stopfile=STOPFILE]
-{--stdin | --infile FILE [--infile FILE ...]} [--wnpath WNPATH]
-[--resnik] [--smooth=SCHEME] | --help | --version
+               {--stdin | --infile FILE [--infile FILE ...]} [--wnpath WNPATH]
+               [--resnik] [--smooth=SCHEME] | --help | --version
 
 =head1 OPTIONS
 
@@ -646,7 +675,7 @@ B<--stopfile>=I<filename>
 B<--wnpath>=I<path>
 
     Location of the WordNet data files (e.g.,
-    /usr/local/WordNet-2.0/dict)
+    /usr/local/WordNet-2.1/dict)
 
 B<--resnik>
 
@@ -686,17 +715,17 @@ B<--infile>=I<PATTERN>
 
 =head1 AUTHORS
 
- Siddharth Patwardhan, University of Utah, Salt Lake City
- sidd @ cs.utah.edu
-
  Ted Pedersen, University of Minnesota, Duluth
- tpederse @ d.umn.edu
+ tpederse at d.umn.edu
 
  Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
- banerjee+ @ cs.cmu.edu
+ banerjee+ at cs.cmu.edu
+
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd at cs.utah.edu
 
  Jason Michelizzi, University of Minnesota, Duluth
- mich0212 @ d.umn.edu
+ mich0212 at d.umn.edu
 
 =head1 BUGS
 
@@ -704,8 +733,7 @@ None.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2004, Siddharth Patwardhan, Ted Pedersen, Satanjeev
-Banerjee, and Jason Michelizzi
+Copyright (c) 2005, Ted Pedersen, Satanjeev Banerjee, Siddharth Patwardhan and Jason Michelizzi
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
