@@ -1,7 +1,7 @@
-#!/usr/local/bin/perl -w
+#! /usr/local/bin/perl -w
 #
-# semCorRawFreq.pl version 0.12
-# (Last updated $Id: semCorRawFreq.pl,v 1.6 2004/10/29 19:25:42 sidz1979 Exp $)
+# semCorRawFreq.pl version 1.01
+# (Last updated $Id: semCorRawFreq.pl,v 1.8 2005/12/11 22:37:02 sidz1979 Exp $)
 #
 # This program reads SemCor files and computes the frequency
 # counts for each synset in WordNet, ignoring the sense tags
@@ -12,7 +12,7 @@
 # by the WordNet::Similarity modules for computing semantic 
 # relatedness.
 #
-# Copyright (c) 2004
+# Copyright (c) 2005
 #
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse at d.umn.edu
@@ -36,10 +36,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 use strict;
-
 use File::Find;
 
 # Variable declarations
@@ -129,8 +128,8 @@ elsif (defined $ENV{WNHOME})
 }
 else
 {
-    $wnPCPath = "C:\\Program Files\\WordNet\\2.0\\dict";
-    $wnUnixPath = "/usr/local/WordNet-2.0/dict";
+    $wnPCPath = "C:\\Program Files\\WordNet\\2.1\\dict";
+    $wnUnixPath = "/usr/local/WordNet-2.1/dict";
 }
 
 
@@ -386,7 +385,7 @@ sub getHyponymOffsets
 	return [@retVal];
     }
     my $wordForm = $wn->getSense($offset, $pos);
-    my @hyponyms = $wn->querySense($wordForm, "hypo");
+    my @hyponyms = $wn->querySense($wordForm, "hypos");
     if(!@hyponyms || $#hyponyms < 0)
     {
 	return undef;
@@ -416,7 +415,7 @@ sub createTopHash
 	{
 	    if(!$wpsOffset{$wn->offset($wps)})
 	    {
-		($upper) = $wn->querySense($wps, "hype");
+		($upper) = $wn->querySense($wps, "hypes");
 		if(!$upper)
 		{
 		    $topHash{"n"}{$wn->offset($wps)} = 1;	
@@ -432,7 +431,7 @@ sub createTopHash
 	{
 	    if(!$wpsOffset{$wn->offset($wps)})
 	    {
-		($upper) = $wn->querySense($wps, "hype");
+		($upper) = $wn->querySense($wps, "hypes");
 		if(!$upper)
 		{
 		    $topHash{"v"}{$wn->offset($wps)} = 1;
@@ -530,8 +529,8 @@ EOU
 # Subroutine to print the version information
 sub printVersion
 {
-    print "semCorRawFreq.pl version 0.12\n";
-    print "Copyright (c) 2004 Ted Pedersen, Satanjeev Banerjee & Siddharth Patwardhan.\n";
+    print "semCorRawFreq.pl version 1.01\n";
+    print "Copyright (c) 2005, Ted Pedersen, Satanjeev Banerjee and Siddharth Patwardhan.\n";
 }
 
 __END__
@@ -569,7 +568,7 @@ B<--resnik>
 B<--wnpath>=I<path>
 
     Location of the WordNet data files (e.g.,
-    /usr/local/WordNet-2.0/dict)
+    /usr/local/WordNet-2.1/dict)
 
 B<--smooth>=I<SCHEME>
 
