@@ -1,12 +1,13 @@
-#!/usr/local/bin/perl -w
+#! /usr/local/bin/perl -w
 #
-# similarity.pl Version 0.07
-# (Updated 12/8/2003 -- JM)
+# similarity.pl version 1.03
+# (Last updated $Id: similarity.pl,v 1.19 2006/04/05 20:15:41 sidz1979 Exp $)
 #
 # This program is a command line interface to WordNet::Similarity
 #
 # Complete documentation is available at the end of this file, or
 # via perldoc similarity.pl
+#
 # ---------------------------------------------------------------------
 
 use strict;
@@ -18,7 +19,7 @@ use strict;
 #  {
 
 # Include the QueryData package.
-use WordNet::QueryData 1.30;
+use WordNet::QueryData 1.39;
 
 # Include library to get Command-Line options.
 use Getopt::Long;
@@ -508,12 +509,12 @@ sub showHelp
     print "               'WordNet::Similarity::edge'   Simple edge-counts (inverted).\n";
     print "               'WordNet::Similarity::hso'    The Hirst St. Onge measure.\n";
     print "               'WordNet::Similarity::lch'    The Leacock Chodorow measure.\n";
-    print "               'WordNet::Similarity::lesk'   Adapted Lesk measure.\n";
+    print "               'WordNet::Similarity::lesk'   Extended Gloss Overlaps measure.\n";
     print "               'WordNet::Similarity::lin'    The Lin measure.\n";
     print "               'WordNet::Similarity::jcn'    The Jiang Conrath measure.\n";
     print "               'WordNet::Similarity::random' A random measure.\n";
     print "               'WordNet::Similarity::res'    The Resnik measure.\n";
-    print "               'WordNet::Similarity::vector' Gloss Vector overlap measure.\n";
+    print "               'WordNet::Similarity::vector_pairs' Gloss Vector overlap measure.\n";
     print "               'WordNet::Similarity::wup'    Wu Palmer measure.\n";
     print "--config      Module-specific configuration file CONFIGFILE. This file\n";
     print "              contains the configuration that is used by the\n";
@@ -540,8 +541,8 @@ sub showHelp
     print "              file with pairs of words separated by newlines, and the\n";
     print "              words of each pair separated by a space.\n";
     print "--wnpath      Option to specify the path of the WordNet data files\n";
-    print "              as PATH. (Defaults to /usr/local/WordNet-2.0/dict on Unix\n";
-    print "              systems and C:\\WordNet\\2.0\\dict on Windows systems)\n";
+    print "              as PATH. (Defaults to /usr/local/WordNet-2.1/dict on Unix\n";
+    print "              systems and C:\\WordNet\\2.1\\dict on Windows systems)\n";
     print "--simpath     If the relatedness module to be used, is locally installed,\n";
     print "              then SIMPATH can be used to indicate the location of the local\n";
     print "              install of the measure.\n";
@@ -563,7 +564,7 @@ sub showHelp
 # Subroutine to display version information.
 sub showVersion
 {
-    print "similarity.pl  version 0.07\n";
+    print "similarity.pl  version 1.03\n";
 
     # 12/8/2003 JM (#3)
     # Print version of module if the --type option was given.
@@ -575,7 +576,7 @@ sub showVersion
       print "$opt_type  version ".$opt_type->VERSION()."\n";
     }
 
-    print "Copyright (c) 2003, Siddharth Patwardhan & Ted Pedersen\n";
+    print "Copyright (c) 2005, Ted Pedersen, Siddharth Patwardhan, Satanjeev Banerjee and Jason Michelizzi.\n";
 }
 
 __END__
@@ -586,7 +587,8 @@ similarity.pl - command line interface to WordNet::Similarity
 
 =head1 SYNOPSIS
 
-similarity.pl [--type=TYPE [--config=CONFIGFILE] [--allsense] [--offsets] [--trace] [--wnpath=PATH] [--simpath=SIMPATH] {--interact | --file=FILENAME | WORD1 WORD2}
+similarity.pl [--type=TYPE [--config=CONFIGFILE] [--allsense] [--offsets] [--trace] 
+              [--wnpath=PATH] [--simpath=SIMPATH] {--interact | --file=FILENAME | WORD1 WORD2}
                | --help
                | --version]
 
@@ -607,9 +609,9 @@ work are denoted with a *):
    (4) Lin (1998) *
    (5) Hirst St-Onge (1998) *
    (6) Wu and Palmer (1994)
-   (7) Adapted Lesk (Banerjee & Pedersen, 2003)
+   (7) Extended Gloss Overlaps (Banerjee & Pedersen, 2003)
    (8) Edge Counting 
-   (9) Vector (Patwardhan, 2003)
+   (9) Gloss Vector (Patwardhan, 2003)
    (10) Random
 
 =head1 OPTIONS
@@ -620,12 +622,12 @@ B<--type>=I<type>
     WordNet::Similarity::edge - simple edge counting
     WordNet::Similarity::hso - Hirst & St-Onge (1998)
     WordNet::Similarity::lch - Leacock & Chodorow (1998)
-    WordNet::Similarity::lesk - Adapted Lesk (Pedersen & Banerjee 2003)
+    WordNet::Similarity::lesk - Extended Gloss Overlaps (Pedersen & Banerjee 2003)
     WordNet::Similarity::lin - Lin (1998)
     WordNet::Similarity::jcn - Jiang & Conrath (1997)
     WordNet::Similarity::random - returns random numbers
     WordNet::Similarity::res - Resnik (1995)
-    WordNet::Similarity::vector - context vector (Patwardhan 2003)
+    WordNet::Similarity::vector - Gloss Vector (Patwardhan 2003)
     WordNet::Similarity::wup - Wu & Palmer (1994)
 
 B<--config>=I<configfile>
@@ -650,7 +652,7 @@ B<--file>=I<filename>
 
 B<--wnpath>=I<path>
     looks for WordNet in I<path>. Usual values are
-    /usr/local/WordNet/2.0/dict and C:\WordNet\2.0\dict.
+    /usr/local/WordNet/2.1/dict and C:\WordNet\2.1\dict.
 
 B<--simpath>=I<path>
     look the relatedness module in I<path>.  This is useful if
@@ -664,10 +666,17 @@ B<--version>
 
 =head1 AUTHORS
 
- Siddharth Patwardhan <sidd at cs.utah.edu>
- Ted Pedersen <tpederse at d.umn.edu>
- Satanjeev Banerjee <satanjeev at cmu.edu>
- Jason Michelizzi <mich0212 at d.umn.edu>
+ Ted Pedersen, University of Minnesota Duluth
+ tpederse at d.umn.edu
+
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd at cs.utah.edu
+
+ Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
+ banerjee+ at cs.cmu.edu
+
+ Jason Michelizzi, University of Minnesota Duluth
+ mich0212 at d.umn.edu
 
 =head1 BUGS
 
@@ -677,16 +686,16 @@ perl(1)
 
 WordNet::Similarity(3)
 
-http://www.cogsci.princeton.edu/~wn/
+http://wordnet.princeton.edu
 
 http://wn-similarity.sourceforge.net
 
-http://groups.yahoo.com/group/wn-similarity/
+http://groups.yahoo.com/group/wn-similarity
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003-2004 Siddharth Patwardhan, Ted Pedersen, Satanjeev
-Banerjee, and Jason Michelizzi
+Copyright (c) 2005, Ted Pedersen, Siddharth Patwardhan, Satanjeev
+Banerjee and Jason Michelizzi
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -703,4 +712,3 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 =cut
-
