@@ -1,16 +1,15 @@
-#!/usr/local/bin/perl -w
+#! /usr/local/bin/perl -w
 #
-# treebankFreq.pl version 0.09
-# (Updated 05/19/2004 -- Jason)
+# treebankFreq.pl version 1.01
+# (Last updated $Id: treebankFreq.pl,v 1.11 2005/12/11 22:37:02 sidz1979 Exp $)
 #
 # This program reads the Treebank Corpus and computes the frequency counts
 # for each synset in WordNet. These frequency counts are used by
 # various measures of semantic relatedness to calculate the information
 # content of concepts. The output is generated in a format as required
-# by the WordNet::Similarity modules (ver 0.01) for computing semantic
-# relatedness.
+# by the WordNet::Similarity modules for computing semantic relatedness.
 #
-# Copyright (c) 2002-2003
+# Copyright (c) 2005
 #
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse at d.umn.edu
@@ -35,7 +34,7 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #
 #
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 # Variable declarations
 my $wn;
@@ -117,8 +116,8 @@ elsif (defined $ENV{WNHOME})
 }
 else
 {
-    $wnPCPath = "C:\\Program Files\\WordNet\\2.0\\dict";
-    $wnUnixPath = "/usr/local/WordNet-2.0/dict";
+    $wnPCPath = "C:\\Program Files\\WordNet\\2.1\\dict";
+    $wnUnixPath = "/usr/local/WordNet-2.1/dict";
 }
 
 
@@ -355,7 +354,7 @@ sub compoundify
 
     while($firstPointer <= $#wordsArray)
     {
-	$secondPointer = $#wordsArray;
+	$secondPointer = (($firstPointer + 5 < $#wordsArray)?($firstPointer + 5):($#wordsArray));
 	$done = 0;
 	while($secondPointer > $firstPointer && !$done)
 	{
@@ -469,7 +468,7 @@ sub getHyponymOffsets
 	return [@retVal];
     }
     $wordForm = $wn->getSense($offset, $pos);
-    @hyponyms = $wn->querySense($wordForm, "hypo");
+    @hyponyms = $wn->querySense($wordForm, "hypos");
     if(!@hyponyms || $#hyponyms < 0)
     {
 	return undef;
@@ -499,7 +498,7 @@ sub createTopHash
 	{
 	    if(!$wpsOffset{$wn->offset($wps)})
 	    {
-		($upper) = $wn->querySense($wps, "hype");
+		($upper) = $wn->querySense($wps, "hypes");
 		if(!$upper)
 		{
 		    $topHash{"n"}{$wn->offset($wps)} = 1;	
@@ -515,7 +514,7 @@ sub createTopHash
 	{
 	    if(!$wpsOffset{$wn->offset($wps)})
 	    {
-		($upper) = $wn->querySense($wps, "hype");
+		($upper) = $wn->querySense($wps, "hypes");
 		if(!$upper)
 		{
 		    $topHash{"v"}{$wn->offset($wps)} = 1;
@@ -573,8 +572,8 @@ sub printUsage
 # Subroutine to print the version information
 sub printVersion
 {
-    print "treebankFreq.pl version 0.09\n";
-    print "Copyright (c) 2002-2004 Ted Pedersen, Satanjeev Banerjee & Siddharth Patwardhan.\n";
+    print "treebankFreq.pl version 1.01\n";
+    print "Copyright (c) 2005, Ted Pedersen, Satanjeev Banerjee and Siddharth Patwardhan.\n";
 }
 
 __END__
@@ -586,7 +585,8 @@ Treebank corpus
 
 =head1 SYNOPSIS
 
-treebankFreq.pl [--compfile=COMPFILE --outfile=OUTFILE [--stopfile=STOPFILE] [--wnpath=WNPATH] [--resnik] [--smooth=SCHEME] PATH | --help -- version]
+treebankFreq.pl [--compfile=COMPFILE --outfile=OUTFILE [--stopfile=STOPFILE] 
+ [--wnpath=WNPATH] [--resnik] [--smooth=SCHEME] PATH | --help -- version]
 
 =head1 OPTIONS
 
@@ -609,7 +609,7 @@ B<--stopfile>=I<filename>
 B<--wnpath>=I<path>
 
     Location of the WordNet data files (e.g.,
-    /usr/local/WordNet-2.0/dict)
+    /usr/local/WordNet-2.1/dict)
 
 B<--resnik>
 
@@ -636,3 +636,4 @@ B<PATH>
 
         treebankFreq.pl [OPTIONS] /home/sid/treebank/raw/wsj
 
+=cut
